#include <iostream>
#include <fstream>
#include <iomanip>
#include <string>
#include <vector>
#include <unordered_map>
#include <unordered_set>
#include <algorithm>
#include <stack>

using namespace std;

using ll = long long;

int up (int n)
{
    int r = 1;

    while (r < n)
        r <<= 1;

    return r;
}

class segtree
{
    vector<int> arr;

    int segmax (int l, int r, int cl, int cr, int v)
    {
        if (r <= cl || cr <= l)
            return -1;
        if (l <= cl && cr <= r)
            return arr[v];

        int ct = (cl + cr) / 2;

        return max (segmax (l, r, cl, ct, 2 * v),
            segmax (l, r, ct, cr, 2 * v + 1));
    }

public:
    segtree (int n, int val = 0) : arr (2 * up (n), val)
    {}

    void add (int wh, int x)
    {
        wh += arr.size () / 2;

        arr[wh] = x;
        wh >>= 1;

        while (wh > 0)
        {
            arr[wh] = max (arr[2 * wh], arr[2 * wh + 1]);
            wh >>= 1;
        }
    }

    int segmax (int l, int r)
    {
        return segmax (l, r, 0, arr.size () / 2, 1);
    }

    int segmax (int l = 0)
    {
        return segmax (l, arr.size () / 2, 0, arr.size () / 2, 1);
    }
};


void build (const vector<int> &arr, vector<vector<pair<int, ll>>> &left)
{
    auto tmp = arr;

    sort (tmp.begin (), tmp.end ());

    segtree st (arr.size (), -1);

    for (int i = 0; i < arr.size (); i++)
    {
        int twh = lower_bound (tmp.begin (), tmp.end (), arr[i]) - tmp.begin ();

        int pr = st.segmax (twh);

        left[i] = {{pr, (i - pr) * (ll)arr[i]}};

        while (left[i].back ().first != -1 &&
            left[i].size () <= left[left[i].back ().first].size ())
        {
            auto nxt = left[left[i].back ().first][left[i].size () - 1];
            nxt.second += left[i].back ().second;

            left[i].push_back (nxt);
        }

        st.add (twh, i);
    }
}


long long seg (const vector<vector<pair<int, ll>>> &left,
    int &last, int tf, int v, int ub)
{
    ub = min (ub, (int)left[v].size () - 1);

    while (ub >= 0 && left[v][ub].first < tf)
        ub--;

    if (ub < 0)
    {
        last = v;

        return 0;
    }

    return left[v][ub].second + seg (left, last, tf, left[v][ub].first, ub);
}


long long ask (const vector<int> &arr, const vector<vector<pair<int, ll>>> &left,
    int in, int out)
{
    int last = 0;
    long long sum = seg (left, last, in, out - 1, numeric_limits<int>::max ());

    sum += left[last].front ().second;

    return sum;
}


void solve (istream &cin = std::cin, ostream &cout = std::cout)
{
    int n;

    cin >> n;
    n--;

    vector<int> arr (n);

    for (auto &it : arr)
        cin >> it;
    auto rra = arr;

    reverse (rra.begin (), rra.end ());

    vector<vector<pair<int, ll>>> left (n), right (n);

    build (arr, left);
    build (rra, right);

    int t;

    cin >> t;

    for (int i = 0; i < t; i++)
    {
        int a, b;

        cin >> a >> b;
        a--;
        b--;

        if (a < b)
            cout << ask (arr, left, a, b) << endl;
        else
            cout << ask (rra, right, arr.size () - a, arr.size () - b) << endl;
    }
}

int main ()
{
    ios_base::sync_with_stdio (false);
    cin.tie (nullptr);

    cout << fixed << setprecision (20);

#ifdef LOCAL
    ifstream fin ("input.txt");

    solve (fin);

    cout << setprecision (4);
    cout << "clock: " << clock () / (double)CLOCKS_PER_SEC << endl;
#else
    solve ();
#endif

    return 0;
}
